aboutsummaryrefslogtreecommitdiff
path: root/core/raw/api.ts
diff options
context:
space:
mode:
Diffstat (limited to 'core/raw/api.ts')
-rw-r--r--core/raw/api.ts10
1 files changed, 5 insertions, 5 deletions
diff --git a/core/raw/api.ts b/core/raw/api.ts
index 06db022..f47dead 100644
--- a/core/raw/api.ts
+++ b/core/raw/api.ts
@@ -1,15 +1,15 @@
-import API from "../api.ts";
+import Core from "../api.ts";
import Parser from "../../language/parser.ts";
import YomikunError from "../../util/error.ts";
-/** @summary internal Yomikun API client (DO NOT USE DIRECTLY) */
-export default class YomikunRAWAPI implements API {
+/** @summary internal Core (DO NOT USE DIRECTLY) */
+export default class RawCore implements Core {
private _parser: Parser;
ready: Promise<void>;
constructor() {
- if (this.constructor === YomikunRAWAPI) {
- throw new YomikunError("YomikunRAWAPI instantiated! please use YomikunDirectAPIClient instead");
+ if (this.constructor === RawCore) {
+ throw new YomikunError("RawCore instantiated! Use DirectCoreClient instead!");
}
this._parser = new Parser();